#
# Copyright (C) 2006 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gettext
_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext

from setroubleshoot.util import *
from setroubleshoot.Plugin import Plugin
import re



class plugin(Plugin):
    summary =_('''
    SELinux is preventing the sasl authentication server from reading the /etc/shadow file.
    ''')

    problem_description = _('''
    SELinux has denied the sasl authentication daemon from reading the
    /etc/shadow file. If the sasl authentication daemon (saslauthd) is
    not setup to read the /etc/shadow, this could signals an
    intrusion.
    ''')

    fix_description = _('''
    If you want the sasl authentication daemon to be able to read
    the /etc/shadow file change the $BOOLEAN boolean: "setsebool -P
    $BOOLEAN=1".
    ''')

    fix_cmd = 'setsebool -P $BOOLEAN=1'

    def __init__(self):
        Plugin.__init__(self, __name__)

    def analyze(self, avcinfo):
        if "read" in avcinfo.avc.access and avcinfo.avc.scontext.type == "saslauthd_t" \
               and avcinfo.avc.tcontext.type == "shadow_t":
            avcinfo.set_template_substitutions(BOOLEAN="allow_saslauthd_read_shadow")
            return self.report(avcinfo, _("Authorization"), self.summary, self.problem_description,
                               self.fix_description, self.fix_cmd)
        else:
            return None

