#
# Copyright (C) 2006 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gettext
_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext

from setroubleshoot.util import *
from setroubleshoot.Plugin import Plugin

class plugin(Plugin):
    summary =_('''
    SELinux is preventing the $SOURCE_PATH ($SOURCE_TYPE) from connecting to port $PORT_NUMBER.
    ''')

    problem_description = _('''
    SELinux has denied the $SOURCE_PATH from connecting to a network port $PORT_NUMBER which does not have an SELinux type associated with it.
    If $SOURCE_PATH is supposed to be allowed to connect on this port, you can use the semanage command to add this port to a port type that $SOURCE_TYPE can connect to.   <i>semanage port -L</i> will list all port types. Please file a <a href="http://bugzilla.redhat.com/bugzilla/enter_bug.cgi">bug report</a> against the selinux-policy package.
If $SOURCE_PATH is not supposed
    to bind to this port, this could signal a intrusion attempt.   
    ''')

    fix_description = _('''
    If you want to allow $SOURCE_PATH to connect to this port
    semanage port -a -t PORT_TYPE -p PROTOCOL $PORT_NUMBER
    Where PORT_TYPE is a type that $SOURCE_TYPE can connect.
    ''')

    fix_cmd = ''
    
    def __init__(self):
        Plugin.__init__(self, __name__)
        self.set_priority(55)

    def analyze(self, avcinfo):
        if "name_connect" in avcinfo.avc.access and \
           avcinfo.avc.tcontext.type == "reserved_port_t" or \
           avcinfo.avc.tcontext.type == "port_t":
                avcinfo.set_template_substitutions(BOOLEAN="httpd_can_network_connect_db")
                return self.report(avcinfo, _("Network Ports"), self.summary, self.problem_description,
                                   self.fix_description, self.fix_cmd)

        return None




