#
# Copyright (C) 2006 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gettext
_ = gettext.translation('setroubleshoot-plugins', '/usr/share/locale', fallback=True).lgettext

from setroubleshoot.util import *
from setroubleshoot.Plugin import Plugin
import re

class plugin(Plugin):
    summary =_('''
    SELinux is preventing the http daemon from executing cgi scripts.
    ''')

    problem_description = _('''
    SELinux has denied the http daemon from executing a cgi
    script. httpd can be setup in a locked down mode where cgi scripts
    are not allowed to be executed.  If the httpd server has been setup
    to not execute cgi scripts, this could signal a intrusion attempt.
    ''')

    fix_description = _('''
    If you want httpd to be able to run cgi scripts, you need to
    turn on the $BOOLEAN boolean: "setsebool -P
    $BOOLEAN=1"
    ''')

    fix_cmd = 'setsebool -P $BOOLEAN=1'
    
    def __init__(self):
        Plugin.__init__(self, __name__)
        
    def analyze(self, avcinfo):
        if avcinfo.avc.scontext.type == "httpd_t" and \
               re.match(".*script_exec_t$", avcinfo.avc.tcontext.type) and \
               avcinfo.avc.accessMatchOne("read getattr search execute transition execute_no_trans"):
            avcinfo.set_template_substitutions(BOOLEAN="httpd_enable_cgi")
            return self.report(avcinfo, _("Web Server"), self.summary, self.problem_description,
                               self.fix_description, self.fix_cmd)

        return None




